@@ -365,7 +365,7 @@ function stream_callbacks.streamopened(session, attr)
 	elseif session.direction == "outgoing" then
 		session.notopen = nil;
 		if not attr.id then
-			log("error", "Stream response did not give us a stream id!");
+			log("warn", "Stream response did not give us a stream id!");
 			session:close({ condition = "undefined-condition", text = "Missing stream ID" });
 			return;
 		end
